Documentation
¶
Index ¶
- Variables
- func RegisterAuthServiceServer(s *grpc.Server, srv AuthServiceServer)
- func RegisterInteractServiceServer(s *grpc.Server, srv InteractServiceServer)
- func RegisterMailServiceServer(s *grpc.Server, srv MailServiceServer)
- func RegisterUserServiceServer(s *grpc.Server, srv UserServiceServer)
- func UsersToNative(in []*User) []*model.User
- type AccessKey
- type AddressInfo
- func (*AddressInfo) Descriptor() ([]byte, []int)deprecated
- func (m AddressInfo) FromNative(n model.AddressInfo) *AddressInfo
- func (x *AddressInfo) GetAddress() string
- func (x *AddressInfo) GetAddress2() string
- func (x *AddressInfo) GetCity() string
- func (x *AddressInfo) GetCountry() string
- func (x *AddressInfo) GetPostalCode() string
- func (x *AddressInfo) GetRegion() string
- func (*AddressInfo) ProtoMessage()
- func (x *AddressInfo) ProtoReflect() protoreflect.Message
- func (x *AddressInfo) Reset()
- func (x *AddressInfo) String() string
- func (m *AddressInfo) ToNative() model.AddressInfo
- type AuthServiceClient
- type AuthServiceServer
- type AuthToken
- func (*AuthToken) Descriptor() ([]byte, []int)deprecated
- func (m AuthToken) FromNative(n *meta.AuthToken) *AuthToken
- func (x *AuthToken) GetExpires() *timestamp.Timestamp
- func (x *AuthToken) GetSuccess() bool
- func (x *AuthToken) GetToken() string
- func (*AuthToken) ProtoMessage()
- func (x *AuthToken) ProtoReflect() protoreflect.Message
- func (x *AuthToken) Reset()
- func (x *AuthToken) String() string
- func (m *AuthToken) ToNative() *meta.AuthToken
- type InteractServiceClient
- type InteractServiceServer
- type LikeRequest
- func (*LikeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LikeRequest) GetEntityID() string
- func (x *LikeRequest) GetUserID() string
- func (*LikeRequest) ProtoMessage()
- func (x *LikeRequest) ProtoReflect() protoreflect.Message
- func (x *LikeRequest) Reset()
- func (x *LikeRequest) String() string
- type LikeResponse
- func (*LikeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *LikeResponse) GetError() string
- func (x *LikeResponse) GetSuccess() bool
- func (*LikeResponse) ProtoMessage()
- func (x *LikeResponse) ProtoReflect() protoreflect.Message
- func (x *LikeResponse) Reset()
- func (x *LikeResponse) String() string
- type MailRequest
- func (*MailRequest) Descriptor() ([]byte, []int)deprecated
- func (x *MailRequest) GetCallbackURL() string
- func (x *MailRequest) GetMessageContent() string
- func (x *MailRequest) GetUserID() string
- func (*MailRequest) ProtoMessage()
- func (x *MailRequest) ProtoReflect() protoreflect.Message
- func (x *MailRequest) Reset()
- func (x *MailRequest) String() string
- type MailServiceClient
- type MailServiceServer
- type PaymentInfo
- func (*PaymentInfo) Descriptor() ([]byte, []int)deprecated
- func (m PaymentInfo) FromNative(n model.PaymentInfo) *PaymentInfo
- func (x *PaymentInfo) GetBillingInfo() *AddressInfo
- func (x *PaymentInfo) GetCVV() string
- func (x *PaymentInfo) GetCardNumber() string
- func (x *PaymentInfo) GetExpires() *YearMonth
- func (*PaymentInfo) ProtoMessage()
- func (x *PaymentInfo) ProtoReflect() protoreflect.Message
- func (x *PaymentInfo) Reset()
- func (x *PaymentInfo) String() string
- func (m *PaymentInfo) ToNative() model.PaymentInfo
- type SubscribeRequest
- func (*SubscribeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SubscribeRequest) GetEmail() string
- func (x *SubscribeRequest) GetUserID() string
- func (*SubscribeRequest) ProtoMessage()
- func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
- func (x *SubscribeRequest) Reset()
- func (x *SubscribeRequest) String() string
- type UnimplementedAuthServiceServer
- func (*UnimplementedAuthServiceServer) GenerateToken(context.Context, *User) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) Guest(context.Context, *AccessKey) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) Login(context.Context, *User) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) Logout(context.Context, *AuthToken) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) Refresh(context.Context, *AuthToken) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) Remote(context.Context, *User) (*AuthToken, error)
- func (*UnimplementedAuthServiceServer) SignUp(context.Context, *User) (*AuthToken, error)
- type UnimplementedInteractServiceServer
- type UnimplementedMailServiceServer
- func (*UnimplementedMailServiceServer) SendEmailConfirmation(context.Context, *MailRequest) (*proto1.CommonResponse, error)
- func (*UnimplementedMailServiceServer) SendNotification(context.Context, *MailRequest) (*proto1.CommonResponse, error)
- func (*UnimplementedMailServiceServer) SendResetPassword(context.Context, *MailRequest) (*proto1.CommonResponse, error)
- func (*UnimplementedMailServiceServer) Subscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
- func (*UnimplementedMailServiceServer) Unsubscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
- type UnimplementedUserServiceServer
- func (*UnimplementedUserServiceServer) AddUsers(context.Context, *UserInput) (*UserResponse, error)
- func (*UnimplementedUserServiceServer) CountUsers(context.Context, *UserFilter) (*UserResponse, error)
- func (*UnimplementedUserServiceServer) DeleteUsers(context.Context, *UserFilter) (*UserResponse, error)
- func (*UnimplementedUserServiceServer) EditUsers(context.Context, *UserInput) (*UserResponse, error)
- func (*UnimplementedUserServiceServer) GetTheme(context.Context, *UserFilter) (*UserTheme, error)
- func (*UnimplementedUserServiceServer) GetUsers(context.Context, *UserFilter) (*UserResponse, error)
- type User
- func (*User) Descriptor() ([]byte, []int)deprecated
- func (m *User) FromNative(n *model.User) *User
- func (x *User) GetAvatar() string
- func (x *User) GetConfirmed() bool
- func (x *User) GetConnectedProviders() map[string]string
- func (x *User) GetEmail() string
- func (x *User) GetEmailN() string
- func (x *User) GetFirstName() string
- func (x *User) GetLastName() string
- func (x *User) GetLiked() []string
- func (x *User) GetLocation() string
- func (x *User) GetPasswordHash() string
- func (x *User) GetPaymentInfo() *PaymentInfo
- func (x *User) GetPhoneNumber() string
- func (x *User) GetProvider() string
- func (x *User) GetRegisterDate() *timestamp.Timestamp
- func (x *User) GetRole() string
- func (x *User) GetSettings() *UserSettings
- func (x *User) GetUniqueID() string
- func (x *User) GetUsername() string
- func (x *User) GetUsernameN() string
- func (*User) ProtoMessage()
- func (x *User) ProtoReflect() protoreflect.Message
- func (x *User) Reset()
- func (x *User) String() string
- func (m *User) ToNative() *model.User
- type UserFilter
- func (*UserFilter) Descriptor() ([]byte, []int)deprecated
- func (x *UserFilter) GetRequestParams() *proto1.RequestParams
- func (x *UserFilter) GetRequestQuery() *_struct.Struct
- func (x *UserFilter) GetUserID() []string
- func (*UserFilter) ProtoMessage()
- func (x *UserFilter) ProtoReflect() protoreflect.Message
- func (x *UserFilter) Reset()
- func (x *UserFilter) String() string
- type UserInput
- func (*UserInput) Descriptor() ([]byte, []int)deprecated
- func (x *UserInput) GetRequestParams() *proto1.RequestParams
- func (x *UserInput) GetUsers() []*User
- func (*UserInput) ProtoMessage()
- func (x *UserInput) ProtoReflect() protoreflect.Message
- func (x *UserInput) Reset()
- func (x *UserInput) String() string
- type UserResponse
- func (*UserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UserResponse) GetCount() int64
- func (x *UserResponse) GetUsers() []*User
- func (*UserResponse) ProtoMessage()
- func (x *UserResponse) ProtoReflect() protoreflect.Message
- func (x *UserResponse) Reset()
- func (x *UserResponse) String() string
- type UserServiceClient
- type UserServiceServer
- type UserSettings
- func (*UserSettings) Descriptor() ([]byte, []int)deprecated
- func (m UserSettings) FromNative(n model.UserSettings) *UserSettings
- func (x *UserSettings) GetLayoutView() string
- func (x *UserSettings) GetTheme() string
- func (*UserSettings) ProtoMessage()
- func (x *UserSettings) ProtoReflect() protoreflect.Message
- func (x *UserSettings) Reset()
- func (x *UserSettings) String() string
- func (m *UserSettings) ToNative() model.UserSettings
- type UserTheme
- type YearMonth
Constants ¶
This section is empty.
Variables ¶
var File_auth_proto protoreflect.FileDescriptor
var File_interact_proto protoreflect.FileDescriptor
var File_mail_proto protoreflect.FileDescriptor
var File_user_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAuthServiceServer ¶
func RegisterAuthServiceServer(s *grpc.Server, srv AuthServiceServer)
func RegisterInteractServiceServer ¶
func RegisterInteractServiceServer(s *grpc.Server, srv InteractServiceServer)
func RegisterMailServiceServer ¶
func RegisterMailServiceServer(s *grpc.Server, srv MailServiceServer)
func RegisterUserServiceServer ¶
func RegisterUserServiceServer(s *grpc.Server, srv UserServiceServer)
Types ¶
type AccessKey ¶
type AccessKey struct {
Key []byte `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*AccessKey) ProtoReflect ¶
func (x *AccessKey) ProtoReflect() protoreflect.Message
type AddressInfo ¶
type AddressInfo struct {
Country string `protobuf:"bytes,1,opt,name=country,proto3" json:"country,omitempty"`
City string `protobuf:"bytes,2,opt,name=city,proto3" json:"city,omitempty"`
Address string `protobuf:"bytes,3,opt,name=address,proto3" json:"address,omitempty"`
Address2 string `protobuf:"bytes,4,opt,name=address2,proto3" json:"address2,omitempty"`
Region string `protobuf:"bytes,5,opt,name=region,proto3" json:"region,omitempty"`
PostalCode string `protobuf:"bytes,6,opt,name=postalCode,proto3" json:"postalCode,omitempty"`
// contains filtered or unexported fields
}
func (*AddressInfo) Descriptor
deprecated
func (*AddressInfo) Descriptor() ([]byte, []int)
Deprecated: Use AddressInfo.ProtoReflect.Descriptor instead.
func (AddressInfo) FromNative ¶
func (m AddressInfo) FromNative(n model.AddressInfo) *AddressInfo
func (*AddressInfo) GetAddress ¶
func (x *AddressInfo) GetAddress() string
func (*AddressInfo) GetAddress2 ¶
func (x *AddressInfo) GetAddress2() string
func (*AddressInfo) GetCity ¶
func (x *AddressInfo) GetCity() string
func (*AddressInfo) GetCountry ¶
func (x *AddressInfo) GetCountry() string
func (*AddressInfo) GetPostalCode ¶
func (x *AddressInfo) GetPostalCode() string
func (*AddressInfo) GetRegion ¶
func (x *AddressInfo) GetRegion() string
func (*AddressInfo) ProtoMessage ¶
func (*AddressInfo) ProtoMessage()
func (*AddressInfo) ProtoReflect ¶
func (x *AddressInfo) ProtoReflect() protoreflect.Message
func (*AddressInfo) Reset ¶
func (x *AddressInfo) Reset()
func (*AddressInfo) String ¶
func (x *AddressInfo) String() string
func (*AddressInfo) ToNative ¶
func (m *AddressInfo) ToNative() model.AddressInfo
type AuthServiceClient ¶
type AuthServiceClient interface {
SignUp(ctx context.Context, in *User, opts ...grpc.CallOption) (*AuthToken, error)
Login(ctx context.Context, in *User, opts ...grpc.CallOption) (*AuthToken, error)
Remote(ctx context.Context, in *User, opts ...grpc.CallOption) (*AuthToken, error)
Guest(ctx context.Context, in *AccessKey, opts ...grpc.CallOption) (*AuthToken, error)
GenerateToken(ctx context.Context, in *User, opts ...grpc.CallOption) (*AuthToken, error)
Refresh(ctx context.Context, in *AuthToken, opts ...grpc.CallOption) (*AuthToken, error)
Logout(ctx context.Context, in *AuthToken, opts ...grpc.CallOption) (*AuthToken, error)
}
AuthServiceClient is the client API for AuthService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewAuthServiceClient ¶
func NewAuthServiceClient(cc grpc.ClientConnInterface) AuthServiceClient
type AuthServiceServer ¶
type AuthServiceServer interface {
SignUp(context.Context, *User) (*AuthToken, error)
Login(context.Context, *User) (*AuthToken, error)
Remote(context.Context, *User) (*AuthToken, error)
Guest(context.Context, *AccessKey) (*AuthToken, error)
GenerateToken(context.Context, *User) (*AuthToken, error)
Refresh(context.Context, *AuthToken) (*AuthToken, error)
Logout(context.Context, *AuthToken) (*AuthToken, error)
}
AuthServiceServer is the server API for AuthService service.
type AuthToken ¶
type AuthToken struct {
Token string `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
Success bool `protobuf:"varint,2,opt,name=success,proto3" json:"success,omitempty"`
Expires *timestamp.Timestamp `protobuf:"bytes,3,opt,name=expires,proto3" json:"expires,omitempty"`
// contains filtered or unexported fields
}
func (*AuthToken) ProtoReflect ¶
func (x *AuthToken) ProtoReflect() protoreflect.Message
type InteractServiceClient ¶
type InteractServiceClient interface {
Like(ctx context.Context, in *LikeRequest, opts ...grpc.CallOption) (*LikeResponse, error)
Unlike(ctx context.Context, in *LikeRequest, opts ...grpc.CallOption) (*LikeResponse, error)
}
InteractServiceClient is the client API for InteractService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewInteractServiceClient ¶
func NewInteractServiceClient(cc grpc.ClientConnInterface) InteractServiceClient
type InteractServiceServer ¶
type InteractServiceServer interface {
Like(context.Context, *LikeRequest) (*LikeResponse, error)
Unlike(context.Context, *LikeRequest) (*LikeResponse, error)
}
InteractServiceServer is the server API for InteractService service.
type LikeRequest ¶
type LikeRequest struct {
UserID string `protobuf:"bytes,1,opt,name=userID,proto3" json:"userID,omitempty"`
EntityID string `protobuf:"bytes,2,opt,name=entityID,proto3" json:"entityID,omitempty"`
// contains filtered or unexported fields
}
func (*LikeRequest) Descriptor
deprecated
func (*LikeRequest) Descriptor() ([]byte, []int)
Deprecated: Use LikeRequest.ProtoReflect.Descriptor instead.
func (*LikeRequest) GetEntityID ¶
func (x *LikeRequest) GetEntityID() string
func (*LikeRequest) GetUserID ¶
func (x *LikeRequest) GetUserID() string
func (*LikeRequest) ProtoMessage ¶
func (*LikeRequest) ProtoMessage()
func (*LikeRequest) ProtoReflect ¶
func (x *LikeRequest) ProtoReflect() protoreflect.Message
func (*LikeRequest) Reset ¶
func (x *LikeRequest) Reset()
func (*LikeRequest) String ¶
func (x *LikeRequest) String() string
type LikeResponse ¶
type LikeResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Error string `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
// contains filtered or unexported fields
}
func (*LikeResponse) Descriptor
deprecated
func (*LikeResponse) Descriptor() ([]byte, []int)
Deprecated: Use LikeResponse.ProtoReflect.Descriptor instead.
func (*LikeResponse) GetError ¶
func (x *LikeResponse) GetError() string
func (*LikeResponse) GetSuccess ¶
func (x *LikeResponse) GetSuccess() bool
func (*LikeResponse) ProtoMessage ¶
func (*LikeResponse) ProtoMessage()
func (*LikeResponse) ProtoReflect ¶
func (x *LikeResponse) ProtoReflect() protoreflect.Message
func (*LikeResponse) Reset ¶
func (x *LikeResponse) Reset()
func (*LikeResponse) String ¶
func (x *LikeResponse) String() string
type MailRequest ¶
type MailRequest struct {
UserID string `protobuf:"bytes,1,opt,name=userID,proto3" json:"userID,omitempty"`
CallbackURL string `protobuf:"bytes,2,opt,name=callbackURL,proto3" json:"callbackURL,omitempty"`
MessageContent string `protobuf:"bytes,3,opt,name=messageContent,proto3" json:"messageContent,omitempty"`
// contains filtered or unexported fields
}
func (*MailRequest) Descriptor
deprecated
func (*MailRequest) Descriptor() ([]byte, []int)
Deprecated: Use MailRequest.ProtoReflect.Descriptor instead.
func (*MailRequest) GetCallbackURL ¶
func (x *MailRequest) GetCallbackURL() string
func (*MailRequest) GetMessageContent ¶
func (x *MailRequest) GetMessageContent() string
func (*MailRequest) GetUserID ¶
func (x *MailRequest) GetUserID() string
func (*MailRequest) ProtoMessage ¶
func (*MailRequest) ProtoMessage()
func (*MailRequest) ProtoReflect ¶
func (x *MailRequest) ProtoReflect() protoreflect.Message
func (*MailRequest) Reset ¶
func (x *MailRequest) Reset()
func (*MailRequest) String ¶
func (x *MailRequest) String() string
type MailServiceClient ¶
type MailServiceClient interface {
SendEmailConfirmation(ctx context.Context, in *MailRequest, opts ...grpc.CallOption) (*proto1.CommonResponse, error)
SendResetPassword(ctx context.Context, in *MailRequest, opts ...grpc.CallOption) (*proto1.CommonResponse, error)
SendNotification(ctx context.Context, in *MailRequest, opts ...grpc.CallOption) (*proto1.CommonResponse, error)
Subscribe(ctx context.Context, in *SubscribeRequest, opts ...grpc.CallOption) (*proto1.CommonResponse, error)
Unsubscribe(ctx context.Context, in *SubscribeRequest, opts ...grpc.CallOption) (*proto1.CommonResponse, error)
}
MailServiceClient is the client API for MailService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewMailServiceClient ¶
func NewMailServiceClient(cc grpc.ClientConnInterface) MailServiceClient
type MailServiceServer ¶
type MailServiceServer interface {
SendEmailConfirmation(context.Context, *MailRequest) (*proto1.CommonResponse, error)
SendResetPassword(context.Context, *MailRequest) (*proto1.CommonResponse, error)
SendNotification(context.Context, *MailRequest) (*proto1.CommonResponse, error)
Subscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
Unsubscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
}
MailServiceServer is the server API for MailService service.
type PaymentInfo ¶
type PaymentInfo struct {
CardNumber string `protobuf:"bytes,1,opt,name=cardNumber,proto3" json:"cardNumber,omitempty"`
Expires *YearMonth `protobuf:"bytes,2,opt,name=expires,proto3" json:"expires,omitempty"`
CVV string `protobuf:"bytes,3,opt,name=cVV,proto3" json:"cVV,omitempty"`
BillingInfo *AddressInfo `protobuf:"bytes,4,opt,name=billingInfo,proto3" json:"billingInfo,omitempty"`
// contains filtered or unexported fields
}
func (*PaymentInfo) Descriptor
deprecated
func (*PaymentInfo) Descriptor() ([]byte, []int)
Deprecated: Use PaymentInfo.ProtoReflect.Descriptor instead.
func (PaymentInfo) FromNative ¶
func (m PaymentInfo) FromNative(n model.PaymentInfo) *PaymentInfo
func (*PaymentInfo) GetBillingInfo ¶
func (x *PaymentInfo) GetBillingInfo() *AddressInfo
func (*PaymentInfo) GetCVV ¶
func (x *PaymentInfo) GetCVV() string
func (*PaymentInfo) GetCardNumber ¶
func (x *PaymentInfo) GetCardNumber() string
func (*PaymentInfo) GetExpires ¶
func (x *PaymentInfo) GetExpires() *YearMonth
func (*PaymentInfo) ProtoMessage ¶
func (*PaymentInfo) ProtoMessage()
func (*PaymentInfo) ProtoReflect ¶
func (x *PaymentInfo) ProtoReflect() protoreflect.Message
func (*PaymentInfo) Reset ¶
func (x *PaymentInfo) Reset()
func (*PaymentInfo) String ¶
func (x *PaymentInfo) String() string
func (*PaymentInfo) ToNative ¶
func (m *PaymentInfo) ToNative() model.PaymentInfo
type SubscribeRequest ¶
type SubscribeRequest struct {
UserID string `protobuf:"bytes,1,opt,name=userID,proto3" json:"userID,omitempty"`
Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
// contains filtered or unexported fields
}
func (*SubscribeRequest) Descriptor
deprecated
func (*SubscribeRequest) Descriptor() ([]byte, []int)
Deprecated: Use SubscribeRequest.ProtoReflect.Descriptor instead.
func (*SubscribeRequest) GetEmail ¶
func (x *SubscribeRequest) GetEmail() string
func (*SubscribeRequest) GetUserID ¶
func (x *SubscribeRequest) GetUserID() string
func (*SubscribeRequest) ProtoMessage ¶
func (*SubscribeRequest) ProtoMessage()
func (*SubscribeRequest) ProtoReflect ¶
func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
func (*SubscribeRequest) Reset ¶
func (x *SubscribeRequest) Reset()
func (*SubscribeRequest) String ¶
func (x *SubscribeRequest) String() string
type UnimplementedAuthServiceServer ¶
type UnimplementedAuthServiceServer struct {
}
UnimplementedAuthServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedAuthServiceServer) GenerateToken ¶
func (*UnimplementedAuthServiceServer) Guest ¶
func (*UnimplementedAuthServiceServer) Login ¶
func (*UnimplementedAuthServiceServer) Logout ¶
func (*UnimplementedAuthServiceServer) Refresh ¶
func (*UnimplementedAuthServiceServer) Remote ¶
type UnimplementedInteractServiceServer ¶
type UnimplementedInteractServiceServer struct {
}
UnimplementedInteractServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedInteractServiceServer) Like ¶
func (*UnimplementedInteractServiceServer) Like(context.Context, *LikeRequest) (*LikeResponse, error)
func (*UnimplementedInteractServiceServer) Unlike ¶
func (*UnimplementedInteractServiceServer) Unlike(context.Context, *LikeRequest) (*LikeResponse, error)
type UnimplementedMailServiceServer ¶
type UnimplementedMailServiceServer struct {
}
UnimplementedMailServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedMailServiceServer) SendEmailConfirmation ¶
func (*UnimplementedMailServiceServer) SendEmailConfirmation(context.Context, *MailRequest) (*proto1.CommonResponse, error)
func (*UnimplementedMailServiceServer) SendNotification ¶
func (*UnimplementedMailServiceServer) SendNotification(context.Context, *MailRequest) (*proto1.CommonResponse, error)
func (*UnimplementedMailServiceServer) SendResetPassword ¶
func (*UnimplementedMailServiceServer) SendResetPassword(context.Context, *MailRequest) (*proto1.CommonResponse, error)
func (*UnimplementedMailServiceServer) Subscribe ¶
func (*UnimplementedMailServiceServer) Subscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
func (*UnimplementedMailServiceServer) Unsubscribe ¶
func (*UnimplementedMailServiceServer) Unsubscribe(context.Context, *SubscribeRequest) (*proto1.CommonResponse, error)
type UnimplementedUserServiceServer ¶
type UnimplementedUserServiceServer struct {
}
UnimplementedUserServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedUserServiceServer) AddUsers ¶
func (*UnimplementedUserServiceServer) AddUsers(context.Context, *UserInput) (*UserResponse, error)
func (*UnimplementedUserServiceServer) CountUsers ¶
func (*UnimplementedUserServiceServer) CountUsers(context.Context, *UserFilter) (*UserResponse, error)
func (*UnimplementedUserServiceServer) DeleteUsers ¶
func (*UnimplementedUserServiceServer) DeleteUsers(context.Context, *UserFilter) (*UserResponse, error)
func (*UnimplementedUserServiceServer) EditUsers ¶
func (*UnimplementedUserServiceServer) EditUsers(context.Context, *UserInput) (*UserResponse, error)
func (*UnimplementedUserServiceServer) GetTheme ¶
func (*UnimplementedUserServiceServer) GetTheme(context.Context, *UserFilter) (*UserTheme, error)
func (*UnimplementedUserServiceServer) GetUsers ¶
func (*UnimplementedUserServiceServer) GetUsers(context.Context, *UserFilter) (*UserResponse, error)
type User ¶
type User struct {
UniqueID string `protobuf:"bytes,1,opt,name=uniqueID,proto3" json:"uniqueID,omitempty"`
Username string `protobuf:"bytes,2,opt,name=username,proto3" json:"username,omitempty"`
UsernameN string `protobuf:"bytes,3,opt,name=usernameN,proto3" json:"usernameN,omitempty"`
Email string `protobuf:"bytes,4,opt,name=email,proto3" json:"email,omitempty"`
EmailN string `protobuf:"bytes,5,opt,name=emailN,proto3" json:"emailN,omitempty"`
PasswordHash string `protobuf:"bytes,6,opt,name=passwordHash,proto3" json:"passwordHash,omitempty"`
FirstName string `protobuf:"bytes,7,opt,name=firstName,proto3" json:"firstName,omitempty"`
LastName string `protobuf:"bytes,8,opt,name=lastName,proto3" json:"lastName,omitempty"`
PhoneNumber string `protobuf:"bytes,9,opt,name=phoneNumber,proto3" json:"phoneNumber,omitempty"`
Avatar string `protobuf:"bytes,10,opt,name=avatar,proto3" json:"avatar,omitempty"`
Location string `protobuf:"bytes,11,opt,name=location,proto3" json:"location,omitempty"`
PaymentInfo *PaymentInfo `protobuf:"bytes,12,opt,name=paymentInfo,proto3" json:"paymentInfo,omitempty"`
Liked []string `protobuf:"bytes,13,rep,name=liked,proto3" json:"liked,omitempty"`
Settings *UserSettings `protobuf:"bytes,14,opt,name=settings,proto3" json:"settings,omitempty"`
Confirmed bool `protobuf:"varint,15,opt,name=confirmed,proto3" json:"confirmed,omitempty"`
Role string `protobuf:"bytes,16,opt,name=role,proto3" json:"role,omitempty"`
RegisterDate *timestamp.Timestamp `protobuf:"bytes,17,opt,name=registerDate,proto3" json:"registerDate,omitempty"`
Provider string `protobuf:"bytes,18,opt,name=provider,proto3" json:"provider,omitempty"`
ConnectedProviders map[string]string `` /* 178-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*User) GetPaymentInfo ¶
func (x *User) GetPaymentInfo() *PaymentInfo
func (*User) GetSettings ¶
func (x *User) GetSettings() *UserSettings
func (*User) ProtoReflect ¶
func (x *User) ProtoReflect() protoreflect.Message
type UserFilter ¶
type UserFilter struct {
UserID []string `protobuf:"bytes,1,rep,name=userID,proto3" json:"userID,omitempty"`
RequestQuery *_struct.Struct `protobuf:"bytes,2,opt,name=requestQuery,proto3" json:"requestQuery,omitempty"`
RequestParams *proto1.RequestParams `protobuf:"bytes,3,opt,name=requestParams,proto3" json:"requestParams,omitempty"`
// contains filtered or unexported fields
}
func (*UserFilter) Descriptor
deprecated
func (*UserFilter) Descriptor() ([]byte, []int)
Deprecated: Use UserFilter.ProtoReflect.Descriptor instead.
func (*UserFilter) GetRequestParams ¶
func (x *UserFilter) GetRequestParams() *proto1.RequestParams
func (*UserFilter) GetRequestQuery ¶
func (x *UserFilter) GetRequestQuery() *_struct.Struct
func (*UserFilter) GetUserID ¶
func (x *UserFilter) GetUserID() []string
func (*UserFilter) ProtoMessage ¶
func (*UserFilter) ProtoMessage()
func (*UserFilter) ProtoReflect ¶
func (x *UserFilter) ProtoReflect() protoreflect.Message
func (*UserFilter) Reset ¶
func (x *UserFilter) Reset()
func (*UserFilter) String ¶
func (x *UserFilter) String() string
type UserInput ¶
type UserInput struct {
Users []*User `protobuf:"bytes,1,rep,name=users,proto3" json:"users,omitempty"`
RequestParams *proto1.RequestParams `protobuf:"bytes,2,opt,name=requestParams,proto3" json:"requestParams,omitempty"`
// contains filtered or unexported fields
}
func (*UserInput) GetRequestParams ¶
func (x *UserInput) GetRequestParams() *proto1.RequestParams
func (*UserInput) ProtoReflect ¶
func (x *UserInput) ProtoReflect() protoreflect.Message
type UserResponse ¶
type UserResponse struct {
Users []*User `protobuf:"bytes,1,rep,name=users,proto3" json:"users,omitempty"`
Count int64 `protobuf:"varint,2,opt,name=count,proto3" json:"count,omitempty"`
// contains filtered or unexported fields
}
func (*UserResponse) Descriptor
deprecated
func (*UserResponse) Descriptor() ([]byte, []int)
Deprecated: Use UserResponse.ProtoReflect.Descriptor instead.
func (*UserResponse) GetCount ¶
func (x *UserResponse) GetCount() int64
func (*UserResponse) GetUsers ¶
func (x *UserResponse) GetUsers() []*User
func (*UserResponse) ProtoMessage ¶
func (*UserResponse) ProtoMessage()
func (*UserResponse) ProtoReflect ¶
func (x *UserResponse) ProtoReflect() protoreflect.Message
func (*UserResponse) Reset ¶
func (x *UserResponse) Reset()
func (*UserResponse) String ¶
func (x *UserResponse) String() string
type UserServiceClient ¶
type UserServiceClient interface {
GetUsers(ctx context.Context, in *UserFilter, opts ...grpc.CallOption) (*UserResponse, error)
CountUsers(ctx context.Context, in *UserFilter, opts ...grpc.CallOption) (*UserResponse, error)
AddUsers(ctx context.Context, in *UserInput, opts ...grpc.CallOption) (*UserResponse, error)
EditUsers(ctx context.Context, in *UserInput, opts ...grpc.CallOption) (*UserResponse, error)
DeleteUsers(ctx context.Context, in *UserFilter, opts ...grpc.CallOption) (*UserResponse, error)
GetTheme(ctx context.Context, in *UserFilter, opts ...grpc.CallOption) (*UserTheme, error)
}
UserServiceClient is the client API for UserService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewUserServiceClient ¶
func NewUserServiceClient(cc grpc.ClientConnInterface) UserServiceClient
type UserServiceServer ¶
type UserServiceServer interface {
GetUsers(context.Context, *UserFilter) (*UserResponse, error)
CountUsers(context.Context, *UserFilter) (*UserResponse, error)
AddUsers(context.Context, *UserInput) (*UserResponse, error)
EditUsers(context.Context, *UserInput) (*UserResponse, error)
DeleteUsers(context.Context, *UserFilter) (*UserResponse, error)
GetTheme(context.Context, *UserFilter) (*UserTheme, error)
}
UserServiceServer is the server API for UserService service.
type UserSettings ¶
type UserSettings struct {
Theme string `protobuf:"bytes,1,opt,name=theme,proto3" json:"theme,omitempty"`
LayoutView string `protobuf:"bytes,2,opt,name=layoutView,proto3" json:"layoutView,omitempty"`
// contains filtered or unexported fields
}
func (*UserSettings) Descriptor
deprecated
func (*UserSettings) Descriptor() ([]byte, []int)
Deprecated: Use UserSettings.ProtoReflect.Descriptor instead.
func (UserSettings) FromNative ¶
func (m UserSettings) FromNative(n model.UserSettings) *UserSettings
func (*UserSettings) GetLayoutView ¶
func (x *UserSettings) GetLayoutView() string
func (*UserSettings) GetTheme ¶
func (x *UserSettings) GetTheme() string
func (*UserSettings) ProtoMessage ¶
func (*UserSettings) ProtoMessage()
func (*UserSettings) ProtoReflect ¶
func (x *UserSettings) ProtoReflect() protoreflect.Message
func (*UserSettings) Reset ¶
func (x *UserSettings) Reset()
func (*UserSettings) String ¶
func (x *UserSettings) String() string
func (*UserSettings) ToNative ¶
func (m *UserSettings) ToNative() model.UserSettings
type UserTheme ¶
type UserTheme struct {
Theme string `protobuf:"bytes,1,opt,name=theme,proto3" json:"theme,omitempty"`
// contains filtered or unexported fields
}
func (*UserTheme) ProtoReflect ¶
func (x *UserTheme) ProtoReflect() protoreflect.Message
type YearMonth ¶
type YearMonth struct {
Year int32 `protobuf:"varint,1,opt,name=year,proto3" json:"year,omitempty"`
Month int32 `protobuf:"varint,2,opt,name=month,proto3" json:"month,omitempty"`
// contains filtered or unexported fields
}
func (*YearMonth) ProtoReflect ¶
func (x *YearMonth) ProtoReflect() protoreflect.Message
Source Files
¶
- auth.pb.go
- cast.go
- interact.pb.go
- mail.pb.go
- user.pb.go